unit FileList;

interface

type
  TFileList = class(TObject)
  public
    Cur: Integer;
    Count: Integer;
    Items: array of string;
    constructor Create;
    procedure Add(const Path: string);
    procedure AddDir(const Path: string);
    procedure Clear;
    procedure Delete(Index: Integer);
    procedure Sort;
  end;

implementation

uses NLib, NSys;

constructor TFileList.Create;
begin
  Clear;
end;

procedure TFileList.Add(const Path: string);
begin
  if Count = Length(Items) then 
    SetLength(Items, Count + Count div 4);
  Items[Count] := Path;
  Inc(Count);
end;

procedure TFileList.AddDir(const Path: string);
var
  dir: TDir;
begin
  with TListDir.Create(Path) do
    try
      while Each(dir) do
        if not (dmDirectory in dir.Mode) then
          Add(JoinPath([Path, dir.Name]));
    finally
      Free;
    end;
end;

procedure TFileList.Clear;
begin
  Count := 0;
  SetLength(Items, 32);
end;

procedure TFileList.Delete(Index: Integer);
var
  i: Integer;
begin
  if (Index < 0) or (Index >= Count) then
    Exit;
  Dec(Count);
  for i := Index to Count - 1 do
    Items[i] := Items[i+1];
end;

procedure TFileList.Sort;
begin
  if Count > 0 then
  begin
    SetLength(Items, Count);
    NLib.Sort(Items, StrColl);
  end;
end;

end.
